# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/com/sun/xml/stream/buffer/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define section free

Name:           sun-xmlstreambuffer
Version:        0.8
Release:        1%{?dist}
Epoch:          0
Summary:        XML Stream Buffer
License:        CDDL
Group:          Development/Libraries/Java
URL:            https://xmlstreambuffer.dev.java.net/
# cvs -d :pserver:guest@cvs.dev.java.net:/cvs login
# cvs -d :pserver:guest@cvs.dev.java.net:/cvs export -r HEAD -d sun-xmlstreambuffer-0.7 xmlstreambuffer/streambuffer
# Use streambuffer.src.zip from glassfish-jaxws-2.1.7 sources in brew to replace existing sources
Source0:        sun-xmlstreambuffer-0.8.tar.bz2
Source1:        http://repo1.maven.org/maven2/com/sun/xml/stream/buffer/streambuffer/0.8/streambuffer-0.8.pom
Source2:        CDDLv1.0.html
Source3:        sun-xmlstreambuffer-component-info.xml
Source4:        sun-xmlstreambuffer-upload.sh
Patch0:         sun-xmlstreambuffer-build-impl.patch

Requires(post): jpackage-utils
Requires(postun): jpackage-utils

Requires:       stax-ex
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  junit
BuildRequires:  glassfish-jaf
BuildRequires:  codehaus-stax-api
BuildRequires:  stax-ex
BuildRequires:  wstx
# To create content for maven2-brew
BuildRequires:  maven-deploy-plugin
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
A stream buffer is a stream-based representation of an XML 
infoset in Java. Stream buffers are designed to: provide 
very efficient stream-based memory representations of XML 
infosets; and be created and processed using any Java-based 
XML API.

Conceptually a stream buffer is similar to the representation
used in the Xerces deferred DOM implementation, with the crucial
difference that a stream buffer does not store hierarchal
information like parent and sibling information. The deferred
DOM implementation reduces memory usage when large XML documents
are parsed but only a subset of the document needs to be processed.
(Note that using deferred DOM will be more expensive than
non-deferred DOM in terms of memory and processing if all
the document is traversed.)

Stream buffers may be used as an efficient alternative to DOM where:

* most or all of an XML infoset will eventually get traversed; and/or

* targeted access to certain parts of an XML infoset are required 
  and need to be efficiently processed using stream-based APIs like
  SAX or StAX.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q 
%patch0 -p0 -b .sav0
%{__cp} -p %{SOURCE2} CDDLv1.0.html
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}
%{__ln_s} $(build-classpath activation) lib/activation.jar
%{__ln_s} $(build-classpath stax_api) lib/jsr173_api.jar
%{__ln_s} $(build-classpath stax-ex) lib/stax-ex.jar
%{__ln_s} $(build-classpath junit) lib/junit.jar
%{__ln_s} $(build-classpath wstx/wstx-asl) lib/wstx-asl.jar

%build
%{ant}

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p dist/streambuffer.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%{__ln_s} %{name}-%{version}.jar %{buildroot}%{_javadir}/streambuffer-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do %{__ln_s} ${jar} `/bin/echo ${jar} | %{__sed} "s|-%{version}||g"`; done)


%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc CDDLv1.0.html
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/streambuffer-%{version}.jar
%{_javadir}*/streambuffer.jar

%changelog
* Thu Dec 09 2010 Hui Wang <huwang@redhat.com> - 0:0.8-1
- Add upload.sh and content of maven2-brew to repolib
- Fix %%files for signed jars

* Fri Sep 17 2010 Martha Benitez <mbenitez@redhat.com> - 0:0.8-0.2.1
- Rebuild to get signatures

* Tue Sep 07 2010 David Walluck <dwalluck@redhat.com> 0:0.8-0.2
- add streambuffer.jar symlink

* Tue Sep 07 2010 David Walluck <dwalluck@redhat.com> 0:0.8-0.1
- 0.8
- remove Requires: stax_1_0_api

* Fri May 07 2010 Martha Benitez <mbenitez@redhat.com> - 0:0.7-5.1
- rebuilt

* Tue Apr 06 2010 Hui Wang <huwang@redhat.com> 0:0.7-5
- Rebuild

* Mon Jun 15 2009 Martha Benitez <mbenitez@redhat.com> 0:0.7-4.1
- Change jpackage-utils >= 0:1.7.4 to jpackage-utils >= 0:1.7.3

* Thu Feb 12 2009 David Walluck <dwalluck@redhat.com> 0:0.7-4
- add repolib

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 0.7-3
- Auto rebuild for JPackage 5 in mock

* Fri Oct 10 2008 David Walluck <dwalluck@redhat.com> 0:0.7-2
- build for JPackage 5

* Wed Apr 09 2007 Ralph Apel <r.apel at r-apel.de> - 0:0.7-1jpp
- First release
